@@ -2,7 +2,7 @@
  * mod_security (apache 1.x), http://www.modsecurity.org/
  * Copyright (c) 2002,2003 Ivan Ristic <ivanr@webkreator.com>
  *
- * $Id: mod_security.c,v 1.49.2.4 2003/11/09 23:38:25 ivanr Exp $
+ * $Id: mod_security.c,v 1.49.2.6 2003/12/05 17:17:00 ivanr Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@ LONG locking_sem = 0;
 
 module MODULE_VAR_EXPORT security_module;
 
-#define MOD_SECURITY_SIGNATURE "mod_security/1.7.3"
+#define MOD_SECURITY_SIGNATURE "mod_security/1.7.4"
 #define AUDIT_BUF_SIZE 8192
 
 #define UNICODE_ERROR_CHARACTERS_MISSING    -1
@@ -978,7 +978,7 @@ static int read_post_payload(request_rec *r, char **p) {
         r->read_length = 0;
         r->remaining = payload_size;
 
-        ap_table_setn(r->notes, ap_pstrdup(r->pool, "mod_security-note"), (char *)rb);
+        ap_table_setn(r->notes, "mod_security-note", (char *)rb);
     
         sec_debug_log(r, 1, "Read %i bytes from POST.", rb->length);
     }
@@ -1096,7 +1096,8 @@ static int sec_check_all_signatures(modsec_rec *msr) {
     // sec_debug_log(r, 1, "Check Unicode encoding: %i", msr->dcfg->check_unicode_encoding);
     msr->_the_request = normalise_uri_inplace(r, msr->_the_request, msr->dcfg->range_start, msr->dcfg->range_end, msr->dcfg->check_encoding, msr->dcfg->check_unicode_encoding);
     if (msr->_the_request == NULL) {
-        ap_table_setn(r->headers_in, ap_pstrdup(r->pool, "mod_security-message"), "Invalid character detected");
+        ap_table_setn(r->headers_in, "mod_security-message", "Invalid character detected");
+        if (msr->dcfg->action.log == 0) ap_table_setn(r->notes, "mod_security-noauditlog", "noauditlog");
         return msr->dcfg->action.status;
     }
     
@@ -1177,9 +1178,11 @@ static int sec_check_all_signatures(modsec_rec *msr) {
             
             if (msr->tmp_message != NULL) {
                 sec_debug_log(r, 1, msr->tmp_message);
-                ap_table_setn(r->headers_in, ap_pstrdup(r->pool, "mod_security-message"), msr->tmp_message);
+                ap_table_setn(r->headers_in, "mod_security-message", msr->tmp_message);
                 if (msr->tmp_log_message) {
                     ap_log_rerror(APLOG_MARK, APLOG_ERR | APLOG_NOERRNO, r, "mod_security: %s", msr->tmp_message);
+                } else {
+                    ap_table_setn(r->notes, "mod_security-noauditlog", "noauditlog");
                 }
             }
 
@@ -1555,7 +1558,7 @@ int check_sig_against_string(modsec_rec *msr, signature *_sig, const char *s, in
             
             sec_debug_log(r, 1, "Executing command \"%s\"", ed->command);
             
-            ap_table_setn(r->headers_in, ap_pstrdup(r->pool, "mod_security-executed"), ed->command);
+            ap_table_setn(r->headers_in, "mod_security-executed", ed->command);
 
             if (!ap_bspawn_child(r->main ? r->main->pool : r->pool, sec_exec_child, (void *)ed, kill_after_timeout, &p1, &p2, &p3)) {
                 ap_log_error(APLOG_MARK, APLOG_ERR | APLOG_NOERRNO, r->server, "mod_security: couldn't spawn child process: %s", sig->exec_string);
@@ -2182,7 +2185,8 @@ static const command_rec sec_cmds[] = {
     { NULL }
 };
 
-static int sec_logger(request_rec *r) {
+static int sec_logger(request_rec *_r) {
+    request_rec *r = find_last_request(_r);
     char *o1 = ap_palloc(r->pool, AUDIT_BUF_SIZE + 1);
     char *o2 = ap_palloc(r->pool, AUDIT_BUF_SIZE + 1);
     sec_dir_config *dcfg = (sec_dir_config *)ap_get_module_config(r->per_dir_config, &security_module);
@@ -2197,8 +2201,6 @@ static int sec_logger(request_rec *r) {
         return DECLINED;
     }
 
-    r = find_last_request(r);
-
     sec_debug_log(r, 2, "sec_logger executed to perform audit log.");
 
     switch(dcfg->auditlog_flag) {
@@ -2210,7 +2212,7 @@ static int sec_logger(request_rec *r) {
             
         case AUDITLOG_DYNAMIC_OR_RELEVANT :
             modsec_message = ap_table_get(r->headers_in, "mod_security-message");
-            if ((modsec_message == NULL)&&(r->handler == NULL)) {
+            if (((modsec_message == NULL)&&(r->handler == NULL))||(ap_table_get(_r->notes, "mod_security-noauditlog") != NULL)) {
                 sec_debug_log(r, 2, "Audit log: ignoring a non-dynamic and non-relevant request [content-type=%s]", r->content_type);
                 return OK;
             }
@@ -2218,7 +2220,7 @@ static int sec_logger(request_rec *r) {
             
         case AUDITLOG_RELEVANT_ONLY :
             modsec_message = ap_table_get(r->headers_in, "mod_security-message");
-            if (modsec_message == NULL) {
+            if ((modsec_message == NULL)||(ap_table_get(_r->notes, "mod_security-noauditlog") != NULL)) {
                 sec_debug_log(r, 2, "Audit log: ignoring a non-relevant request [content-type=%s]", r->content_type);
                 return OK;
             }
@@ -2393,7 +2395,7 @@ static int sec_check_access(request_rec *r) {
     // make a note for the logger
     if (rc != DECLINED) {
         char *note = ap_psprintf(r->pool, "%i", rc);
-        ap_table_setn(r->headers_in, ap_pstrdup(r->pool, "mod_security-action"), note);
+        ap_table_setn(r->headers_in, "mod_security-action", note);
     }
     
     return rc;
